@@ -3,7 +3,7 @@ BEGIN {
   $App::Installer::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $App::Installer::VERSION = '0.004';
+  $App::Installer::VERSION = '0.005';
 }
 # ABSTRACT: Application class for Installer
 
@@ -12,17 +12,22 @@ use Path::Class;
 use IO::All;
 use namespace::clean;
 
-has 'target' => (
+has target => (
   is => 'ro',
   required => 1,
 );
 
-has 'file' => (
+has file => (
   is => 'ro',
   lazy => 1,
   default => sub { '.installer' },
 );
 
+has installer_code => (
+  is => 'ro',
+  predicate => 1,
+);
+
 has 'url' => (
   is => 'ro',
   predicate => 1,
@@ -39,7 +44,9 @@ sub install_to_target {
   my $target = $self->target;
   $target = dir($target)->absolute->stringify;
   my $installer_code;
-  if ($self->has_url) {
+  if ($self->has_installer_code) {
+    $installer_code = $self->installer_code;
+  } elsif ($self->has_url) {
     $installer_code = io($self->url)->get->content;
   } else {
     $installer_code = io($self->file_path)->all;
@@ -79,7 +86,7 @@ App::Installer - Application class for Installer
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 DESCRIPTION
 
